# Conda Project Examples

This directory contains example project directories showing
specific features of Conda Project.
In this README the example projects are shown in order of
increasing complexity.
See the individual README files for more details.

* `env-file-only`: A project that contains only an `environment.yml` file.
* `condarc-settings`: Use the local `.condarc` file to adjust conda settings.
* `mutli-env-files`: Use the `conda-project.yml` file to define multiple environments within a project.
* `cmds-and-vars`: Use the `conda-project.yml` file to define runable commands and set environment variables.
